@@ -1,16 +1,16 @@
-# $Id: install.py 1102 2014-11-12 23:02:21Z mwall $
+# $Id: install.py 1227 2015-01-25 13:12:27Z mwall $
 # installer for ThinkSpeak
 # Copyright 2014 Matthew Wall
 
 from setup import ExtensionInstaller
 
 def loader():
-    return ThinkSpeakInstaller()
+    return ThingSpeakInstaller()
 
 class ThingSpeakInstaller(ExtensionInstaller):
     def __init__(self):
         super(ThingSpeakInstaller, self).__init__(
-            version="0.1",
+            version="0.2",
             name='thingspeak',
             description='Upload weather data to ThingSpeak.',
             author="Matthew Wall",
